aboutsummaryrefslogtreecommitdiff
path: root/kernel/include/rpmsg/ethosu_rpmsg_network.h
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/include/rpmsg/ethosu_rpmsg_network.h')
-rw-r--r--kernel/include/rpmsg/ethosu_rpmsg_network.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kernel/include/rpmsg/ethosu_rpmsg_network.h b/kernel/include/rpmsg/ethosu_rpmsg_network.h
index 269018a..40819ce 100644
--- a/kernel/include/rpmsg/ethosu_rpmsg_network.h
+++ b/kernel/include/rpmsg/ethosu_rpmsg_network.h
@@ -17,8 +17,8 @@
* http://www.gnu.org/licenses/gpl-2.0.html.
*/
-#ifndef ETHOSU_NETWORK_H
-#define ETHOSU_NETWORK_H
+#ifndef ETHOSU_RPMSG_NETWORK_H
+#define ETHOSU_RPMSG_NETWORK_H
/****************************************************************************
* Includes
@@ -36,13 +36,13 @@ struct ethosu_uapi_network_create;
struct device;
struct file;
-struct ethosu_network {
- struct device *dev;
- struct ethosu_mailbox *mailbox;
- struct file *file;
- struct kref kref;
- struct ethosu_dma_mem *dma_mem;
- uint32_t index;
+struct ethosu_rpmsg_network {
+ struct device *dev;
+ struct ethosu_rpmsg_mailbox *mailbox;
+ struct file *file;
+ struct kref kref;
+ struct ethosu_dma_mem *dma_mem;
+ uint32_t index;
};
/****************************************************************************
@@ -50,35 +50,35 @@ struct ethosu_network {
****************************************************************************/
/**
- * ethosu_network_create() - Create network
+ * ethosu_rpmsg_network_create() - Create network
*
* This function must be called in the context of a user space process.
*
* Return: fd on success, else error code.
*/
-int ethosu_network_create(struct device *dev,
- struct ethosu_mailbox *mailbox,
- struct ethosu_uapi_network_create *uapi);
+int ethosu_rpmsg_network_create(struct device *dev,
+ struct ethosu_rpmsg_mailbox *mailbox,
+ struct ethosu_uapi_network_create *uapi);
/**
* ethosu_network_get_from_fd() - Get network handle from fd
*
* This function must be called from a user space context.
*
* Return: Pointer on success, else ERR_PTR.
*/
-struct ethosu_network *ethosu_network_get_from_fd(int fd);
+struct ethosu_rpmsg_network *ethosu_rpmsg_network_get_from_fd(int fd);
/**
- * ethosu_network_get() - Get network
+ * ethosu_rpmsg_network_get() - Get network
*/
-void ethosu_network_get(struct ethosu_network *net);
+void ethosu_rpmsg_network_get(struct ethosu_rpmsg_network *net);
/**
- * ethosu_network_put() - Put network
+ * ethosu_rpmsg_network_put() - Put network
*
* Return: 1 if object was removed, else 0.
*/
-int ethosu_network_put(struct ethosu_network *net);
+int ethosu_rpmsg_network_put(struct ethosu_rpmsg_network *net);
-#endif /* ETHOSU_NETWORK_H */
+#endif /* ETHOSU_RPMSG_NETWORK_H */
@@ -50,35 +50,35 @@ struct ethosu_network {
/**
- * ethosu_network_get_from_fd() - Get network handle from fd
+ * ethosu_rpmsg_network_get_from_fd() - Get network handle from fd
*
* This function must be called from a user space context.